@@ -3,6 +3,7 @@ from typing import Any, Callable, List, Tuple, Type
 
 from dataclasses_jsonschema import JsonSchemaMixin
 from typed_ast import ast3 as ast
+from typed_ast.ast3 import Num
 
 from arcor2.cached import CachedProject as CProject
 from arcor2.cached import CachedScene as CScene
@@ -96,6 +97,12 @@ class IntegerPlugin(ParameterPlugin):
     def _value_from_json(cls, value: str) -> int:
         return super(IntegerPlugin, cls)._value_from_json(value)
 
+    @classmethod
+    def parameter_ast(
+        cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
+    ) -> Num:
+        return Num(n=cls.parameter_execution_value(type_defs, scene, project, action_id, parameter_id))
+
 
 class IntegerListPlugin(ListParameterPlugin):
     @classmethod
@@ -104,7 +111,7 @@ class IntegerListPlugin(ListParameterPlugin):
 
     @classmethod
     def type_name(cls) -> str:
-        return get_type_name(IntegerPlugin)  # type: ignore
+        return get_type_name(IntegerPlugin)
 
     @classmethod
     def meta(cls, param_meta: ParameterMeta, action_method: Callable, action_node: ast.FunctionDef) -> None:
